#
# spec file for package yubikey-manager-qt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bname ykman-gui
Name:           yubikey-manager-qt
Version:        1.1.1
Release:        lp150.2.3.1
Summary:        Graphical application for configuring a YubiKey
License:        BSD-2-Clause
Group:          Productivity/Security
URL:            https://developers.yubico.com/yubikey-manager-qt/Releases
Source0:        https://developers.yubico.com/yubikey-manager-qt/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/yubikey-manager-qt/Releases/%{name}-%{version}.tar.gz.sig
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python3)
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Requires:       python3-pyotherside
Requires:       python3-yubikey-manager >= 1.0.1

%description
A graphical application for configuring a YubiKey over all transport modes..

%prep
%setup -q -n yubikey-manager-qt
# Fix build for Leap 15 and SLE 15
sed -i 's|python |python3 |g' ykman-cli/ykman-cli.pro
sed -i 's|python |python3 |g' ykman-gui/ykman-gui.pro

%build
qmake-qt5 QMAKE_CFLAGS+="%{optflags}" QMAKE_CXXFLAGS+="%{optflags}" QMAKE_STRIP="/bin/true";
make %{?_smp_mflags}

%install
make install INSTALL_ROOT="%{buildroot}";
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -p -m 0644 resources/icons/ykman.png %{buildroot}%{_datadir}/pixmaps/
%suse_update_desktop_file -i %{bname} System Security

%files
%doc NEWS README
%{_bindir}/%{bname}
%{_datadir}/applications/%{bname}.desktop
%{_datadir}/pixmaps/ykman.png

%changelog
* Mon Mar 11 2019 Karol Babioch <kbabioch@suse.de>
- Version 1.1.1 (released 2019-03-11)
  * PIV: On import, do not always verify that the certifcate and private key
    matches, since it may require the PIN
  * PIV: Report if private key or certificate was imported
  * PIV: Improve handling of malformed certificates
  * PIV: Allow uppercase characters in management key input field
- Fixed path issue with setup macro during build
* Wed Jan  9 2019 Karol Babioch <kbabioch@suse.de>
- Update to version 1.1.0 (released 2019-01-09):
  * Add support for Security Key NFC
  * Add support for managing PIV Application
  * Bugfix: OATH-HOTP credentials was always configured with 6 digits
  * UI: Replace Succes-popups with Snackbar-messages
  * UX: Drop confirmation prompt for OTP Swap Slots
* Tue Nov 13 2018 Karol Babioch <kbabioch@suse.com>
- Fixed dependency issues:
  * python3-pyotherside (explicitly require python3 module)
  * libqt5-qtgraphicaleffects (bsc#1115816)
  * libqt5-qtquickcontrols & libqt5-qtquickcontrols2 (bsc#1115595)
* Wed Oct 10 2018 Karol Babioch <kbabioch@suse.com>
- Bumped required version of yubikey-manager to 1.0.1
* Wed Oct 10 2018 Karol Babioch <kbabioch@suse.com>
- Version 1.0.1 (released 2018-10-10)
  * Support for YubiKey 5A
  * Bugfix: Show picture for FIDO U2F Security key
  * Bugfix: Swapping OTP slots or deleting OTP a slot configuration now reloads the view
  * Bugfix: Under some conditions the wrong device info was shown
* Thu Sep 27 2018 Karol Babioch <kbabioch@suse.com>
- Version 1.0.0 (released 2018-09-24)
  * Completely new UI
  * Support for YubiKey 5 Series
  * Support for configuring NFC and USB interfaces
  * Linux: Release as AppImage (experimental)
* Wed Jul 11 2018 kbabioch@suse.com
- Version 0.5.2 (released 2018-07-09)
  * Support for YubiKey FIPS.-
- Applied spec-cleaner
- Adjusted setup macro, since source tarball does not contain a
  top-level directory (i.e. tar bomb)
* Wed May  9 2018 kbabioch@suse.com
- Version 0.5.1:
  * Support changing USB interfaces for YubiKey Preview.
  * OATH-HOTP: Show correct error message on too long secret keys.
  * CLI: Give correct exit codes.
* Tue Apr 17 2018 kbabioch@suse.com
- Version 0.5.0:
  * Support for configuring YubiKeys with FIDO2.
  * OTP: Configuring HOTP now correctly supports 8 or 6 characters.
  * Static password: Any character can now be used in a static password.
  * UI: New header with help-link added.
  * New icon.
- Cleaned up spec file (spec-cleaner)
* Tue Apr  3 2018 t.gruner@katodev.de
- Fix build for Leap 15 and SLE 15
* Wed Mar 14 2018 meissner@suse.com
- require the libqt5-qtquickcontrols for the QML Dialog and Controls.
  (bsc#1085147)
* Thu Mar  1 2018 meissner@suse.com
- add python buildrequires.
* Wed Jan  3 2018 t.gruner@katodev.de
- Version 0.4.0
  - Update CLI version to ykman 0.5.0
  - Now requires ykman version >= 0.5.0
  - Features:
  - Now differentiates between disabled and unavailable features
  - Added --log-level CLI option with same function as --log-level option to ykman version 0.5.0; see ykman --help for usage
  - Bufixes:
  - Made main view and Configure Connections dialog respond to resizing window
* Fri Dec  1 2017 t.gruner@katodev.de
- Initial release version 0.3.2
